==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkMolecule.java <==
// java wrapper for vtkMolecule object
//

package vtk;
import vtk.*;

public class vtkMolecule extends vtkUndirectedGraph
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native int GetDataObjectType_3();
  public int GetDataObjectType()
    { return GetDataObjectType_3(); }

  private native int GetNumberOfAtoms_4();
  public int GetNumberOfAtoms()
    { return GetNumberOfAtoms_4(); }

  private native int GetNumberOfBonds_5();
  public int GetNumberOfBonds()
    { return GetNumberOfBonds_5(); }

  private native int GetAtomAtomicNumber_6(int id0);
  public int GetAtomAtomicNumber(int id0)
    { return GetAtomAtomicNumber_6(id0); }

  private native void SetAtomAtomicNumber_7(int id0,int id1);
  public void SetAtomAtomicNumber(int id0,int id1)
    { SetAtomAtomicNumber_7(id0,id1); }

  private native void SetAtomPosition_8(int id0,double id1,double id2,double id3);
  public void SetAtomPosition(int id0,double id1,double id2,double id3)
    { SetAtomPosition_8(id0,id1,id2,id3); }

  private native void GetAtomPosition_9(int id0,double id1[]);
  public void GetAtomPosition(int id0,double id1[])
    { GetAtomPosition_9(id0,id1); }

  private native void SetBondOrder_10(int id0,int id1);
  public void SetBondOrder(int id0,int id1)
    { SetBondOrder_10(id0,id1); }

  private native int GetBondOrder_11(int id0);
  public int GetBondOrder(int id0)
    { return GetBondOrder_11(id0); }

  private native double GetBondLength_12(int id0);
  public double GetBondLength(int id0)
    { return GetBondLength_12(id0); }

  private native long GetAtomicPositionArray_13();
  public vtkPoints GetAtomicPositionArray() {
    long temp = GetAtomicPositionArray_13();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetAtomicNumberArray_14();
  public vtkUnsignedShortArray GetAtomicNumberArray() {
    long temp = GetAtomicNumberArray_14();

    if (temp == 0) return null;
    return (vtkUnsignedShortArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetElectronicData_15();
  public vtkAbstractElectronicData GetElectronicData() {
    long temp = GetElectronicData_15();

    if (temp == 0) return null;
    return (vtkAbstractElectronicData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetElectronicData_16(vtkAbstractElectronicData id0);
  public void SetElectronicData(vtkAbstractElectronicData id0)
    { SetElectronicData_16(id0); }

  private native boolean CheckedShallowCopy_17(vtkGraph id0);
  public boolean CheckedShallowCopy(vtkGraph id0)
    { return CheckedShallowCopy_17(id0); }

  private native boolean CheckedDeepCopy_18(vtkGraph id0);
  public boolean CheckedDeepCopy(vtkGraph id0)
    { return CheckedDeepCopy_18(id0); }

  private native void ShallowCopy_19(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_19(id0); }

  private native void DeepCopy_20(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_20(id0); }

  private native void ShallowCopyStructure_21(vtkMolecule id0);
  public void ShallowCopyStructure(vtkMolecule id0)
    { ShallowCopyStructure_21(id0); }

  private native void DeepCopyStructure_22(vtkMolecule id0);
  public void DeepCopyStructure(vtkMolecule id0)
    { DeepCopyStructure_22(id0); }

  private native void ShallowCopyAttributes_23(vtkMolecule id0);
  public void ShallowCopyAttributes(vtkMolecule id0)
    { ShallowCopyAttributes_23(id0); }

  private native void DeepCopyAttributes_24(vtkMolecule id0);
  public void DeepCopyAttributes(vtkMolecule id0)
    { DeepCopyAttributes_24(id0); }

  private native boolean HasLattice_25();
  public boolean HasLattice()
    { return HasLattice_25(); }

  private native void ClearLattice_26();
  public void ClearLattice()
    { ClearLattice_26(); }

  private native void SetLattice_27(vtkMatrix3x3 id0);
  public void SetLattice(vtkMatrix3x3 id0)
    { SetLattice_27(id0); }

  private native long GetLattice_28();
  public vtkMatrix3x3 GetLattice() {
    long temp = GetLattice_28();

    if (temp == 0) return null;
    return (vtkMatrix3x3)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkMolecule() { super(); }

  public vtkMolecule(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkMolecule.java <==
// java wrapper for vtkMolecule object
//

package vtk;
import vtk.*;

public class vtkMolecule extends vtkUndirectedGraph
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native int GetDataObjectType_3();
  public int GetDataObjectType()
    { return GetDataObjectType_3(); }

  private native int GetNumberOfAtoms_4();
  public int GetNumberOfAtoms()
    { return GetNumberOfAtoms_4(); }

  private native int GetNumberOfBonds_5();
  public int GetNumberOfBonds()
    { return GetNumberOfBonds_5(); }

  private native int GetAtomAtomicNumber_6(int id0);
  public int GetAtomAtomicNumber(int id0)
    { return GetAtomAtomicNumber_6(id0); }

  private native void SetAtomAtomicNumber_7(int id0,int id1);
  public void SetAtomAtomicNumber(int id0,int id1)
    { SetAtomAtomicNumber_7(id0,id1); }

  private native void SetAtomPosition_8(int id0,double id1,double id2,double id3);
  public void SetAtomPosition(int id0,double id1,double id2,double id3)
    { SetAtomPosition_8(id0,id1,id2,id3); }

  private native void GetAtomPosition_9(int id0,double id1[]);
  public void GetAtomPosition(int id0,double id1[])
    { GetAtomPosition_9(id0,id1); }

  private native void SetBondOrder_10(int id0,int id1);
  public void SetBondOrder(int id0,int id1)
    { SetBondOrder_10(id0,id1); }

  private native int GetBondOrder_11(int id0);
  public int GetBondOrder(int id0)
    { return GetBondOrder_11(id0); }

  private native double GetBondLength_12(int id0);
  public double GetBondLength(int id0)
    { return GetBondLength_12(id0); }

  private native long GetAtomicPositionArray_13();
  public vtkPoints GetAtomicPositionArray() {
    long temp = GetAtomicPositionArray_13();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetAtomicNumberArray_14();
  public vtkUnsignedShortArray GetAtomicNumberArray() {
    long temp = GetAtomicNumberArray_14();

    if (temp == 0) return null;
    return (vtkUnsignedShortArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetElectronicData_15();
  public vtkAbstractElectronicData GetElectronicData() {
    long temp = GetElectronicData_15();

    if (temp == 0) return null;
    return (vtkAbstractElectronicData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetElectronicData_16(vtkAbstractElectronicData id0);
  public void SetElectronicData(vtkAbstractElectronicData id0)
    { SetElectronicData_16(id0); }

  private native boolean CheckedShallowCopy_17(vtkGraph id0);
  public boolean CheckedShallowCopy(vtkGraph id0)
    { return CheckedShallowCopy_17(id0); }

  private native boolean CheckedDeepCopy_18(vtkGraph id0);
  public boolean CheckedDeepCopy(vtkGraph id0)
    { return CheckedDeepCopy_18(id0); }

  private native void ShallowCopy_19(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_19(id0); }

  private native void DeepCopy_20(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_20(id0); }

  private native void ShallowCopyStructure_21(vtkMolecule id0);
  public void ShallowCopyStructure(vtkMolecule id0)
    { ShallowCopyStructure_21(id0); }

  private native void DeepCopyStructure_22(vtkMolecule id0);
  public void DeepCopyStructure(vtkMolecule id0)
    { DeepCopyStructure_22(id0); }

  private native void ShallowCopyAttributes_23(vtkMolecule id0);
  public void ShallowCopyAttributes(vtkMolecule id0)
    { ShallowCopyAttributes_23(id0); }

  private native void DeepCopyAttributes_24(vtkMolecule id0);
  public void DeepCopyAttributes(vtkMolecule id0)
    { DeepCopyAttributes_24(id0); }

  private native boolean HasLattice_25();
  public boolean HasLattice()
    { return HasLattice_25(); }

  private native void ClearLattice_26();
  public void ClearLattice()
    { ClearLattice_26(); }

  private native void SetLattice_27(vtkMatrix3x3 id0);
  public void SetLattice(vtkMatrix3x3 id0)
    { SetLattice_27(id0); }

  private native long GetLattice_28();
  public vtkMatrix3x3 GetLattice() {
    long temp = GetLattice_28();

    if (temp == 0) return null;
    return (vtkMatrix3x3)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkMolecule() { super(); }

  public vtkMolecule(long id) { super(id); }
  public native long   VTKInit();

}
